Find the nearest neighbors

FindNNDist(fullcluster, normCount, meaningn = 20)

Arguments

fullcluster

A list of clusters that generated by the function GetCluster().

normCount

A list of normalized gene count matrix generated by the function NormData().

meaningn

Positive integer giving the number of nearest-neighbor distances to retain for each sampled cell. Defaults to 20.

Value

A list of distance vectors

Examples

data(sim_result)
distances <- FindNNDist(sim_result[[1]], sim_result[[2]], meaningn = 20)
#> 
  |                                                                  
  |                                                            |   0%
  |                                                                  
  |====================                                        |  33%
  |                                                                  
  |========================================                    |  67%
  |                                                                  
  |============================================================| 100%
length(distances)
#> [1] 3