This function takes a SingleCellExperiment object and a variable by which to split it, converts it to a Seurat object, and then splits it according to the specified variable.

SCEtoSeurat(sce)

Arguments

sce

A SingleCellExperiment object.

Value

A Seurat objects.

Examples

data(sim_data_sce)
seuratobj <- SCEtoSeurat(sim_data_sce)
#> Warning: No gene metadata columns found to add to Seurat object.
seuratobj
#> An object of class Seurat 
#> 3000 features across 800 samples within 1 assay 
#> Active assay: RNA (3000 features, 0 variable features)
#>  1 layer present: counts