Permutation Test
PermTest(fullcluster, distmat, firstn = 15)A list of clusters that generated by the function GetCluster()
A list of distance vectors generated by the function FindNNDist().
Positive integer giving the number of nearest neighbors from
each sampled cell to include. It must not exceed the meaningn value used
to create distmat. The published method uses 15.
A list containing the relative within-between distance matrix
(allrevDiff) and permutation-test p-values (allP).
data(sim_result)
# fullcluster <- GetCluster(seuratlist)
# Assuming 'distmat' is a list of normalized gene count matrix
# distmat <- FindNNDist(fullcluster, normCount, meaningn = 20)
testres <- PermTest(sim_result[[1]], sim_result[[3]], 15)